Package: terraTCGAdata
Type: Package
Title: OpenAccess TCGA Data on Terra as MultiAssayExperiment
Version: 1.17.1
Authors@R: c(
    person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3242-0582")),
    person("NHGRI", role = "fnd",
           comment = c(GrantNo. = "U24HG010263"))
  )
Description: Leverage the existing open access TCGA data on Terra with
    well-established Bioconductor infrastructure. Make use of the Terra
    data model without learning its complexities. With a few functions,
    you can copy / download and generate a MultiAssayExperiment from the
    TCGA example workspaces provided by Terra.
Depends: AnVILGCP, MultiAssayExperiment
biocViews: Software, Infrastructure, DataImport
Imports: AnVIL, BiocFileCache, dplyr, GenomicRanges, methods,
        RaggedExperiment, readr, S4Vectors, stats, tidyr, TCGAutils,
        utils
Suggests: AnVILBase, GCPtools, knitr, rmarkdown, BiocStyle, withr,
        testthat (>= 3.0.0)
URL: https://github.com/waldronlab/terraTCGAdata
BugReports: https://github.com/waldronlab/terraTCGAdata/issues
VignetteBuilder: knitr
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
Date: 2025-11-17
git_url: https://git.bioconductor.org/packages/terraTCGAdata
git_branch: devel
git_last_commit: ffca88e
git_last_commit_date: 2026-04-29
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:39:43 UTC; biocbuild
Author: Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  NHGRI [fnd] (GrantNo.: U24HG010263)
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
Built: R 4.6.0; ; 2026-05-19 05:12:09 UTC; unix

# Generated by roxygen2: do not edit by hand

export(getAssayData)
export(getAssayTable)
export(getClinical)
export(getClinicalTable)
export(getTCGAdatalist)
export(sampleTypesTable)
export(selectTCGAworkspace)
export(terraTCGAdata)
export(terraTCGAworkspace)
import(AnVIL)
import(MultiAssayExperiment)
importFrom(AnVILGCP,avcopy)
importFrom(AnVILGCP,avtable)
importFrom(AnVILGCP,avworkspaces)

# terraTCGAData

## Installation

``` r
if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("terraTCGAdata")
```

# Overview

The `terraTCGAdata` R package aims to import TCGA datasets, as
[MultiAssayExperiment](http://bioconductor.org/packages/MultiAssayExperiment/),
available on the Terra platform. The package provides a set of functions
that allow the discovery of relevant datasets. It provides one main
function and two helper functions:

1.  `terraTCGAdata` allows the creation of the `MultiAssayExperiment`
    object from the different indicated resources.

2.  The `getClinicalTable` and `getAssayTable` functions allow for the
    discovery of datasets within the Terra data model. The column names
    from these tables can be provided as inputs to the `terraTCGAdata`
    function.

## Data

Some public Terra workspaces come pre-packaged with TCGA data (i.e.,
cloud data resources are linked within the data model). Particularly the
workspaces that are labelled `OpenAccess_V1-0`. Datasets harmonized to
the hg38 genome, such as those from the Genomic Data Commons data
repository, use a different data model / workflow and are not compatible
with the functions in this package. For those that are, we make use of
the Terra data model and represent the data as `MultiAssayExperiment`.

For more information on `MultiAssayExperiment`, please see the vignette
in that package.

# Requirements

## Loading packages

``` r
library(AnVIL)
library(terraTCGAdata)
```

## gcloud sdk installation

A valid GCloud SDK installation is required to use the package. To get
set up, see the Bioconductor tutorials for running RStudio on Terra. Use
the `gcloud_exists()` function from the
*[AnVIL](https://bioconductor.org/packages/3.16/AnVIL)* package to
identify whether it is installed in your system.

``` r
gcloud_exists()
#> [1] TRUE
```

You can also use the `gcloud_project` to set a project name by
specifying the project argument:

``` r
gcloud_project()
#> [1] "bioconductor-rpci-anvil"
```

# Default Data Workspace

To get a table of available TCGA workspaces, use the
`selectTCGAworkspace()` function:

``` r
selectTCGAworkspace()
#> [1] "TCGA_COAD_OpenAccess_V1-0_DATA"
```

You can also set the package-wide option with the `terraTCGAworkspace`
function and check the setting with
`getOption('terraTCGAdata.workspace')` or by running
`terraTCGAworkspace` function.

``` r
terraTCGAworkspace("TCGA_COAD_OpenAccess_V1-0_DATA")
#> [1] "TCGA_COAD_OpenAccess_V1-0_DATA"
getOption("terraTCGAdata.workspace")
#> [1] "TCGA_COAD_OpenAccess_V1-0_DATA"
```

# Clinical data resources

In order to determine what datasets to download, use the
`getClinicalTable` function to list all of the columns that correspond
to clinical data from the different collection centers.

``` r
ct <- getClinicalTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
#> Using namespace/workspace: broad-firecloud-tcga/TCGA_COAD_OpenAccess_V1-0_DATA
ct
#> # A tibble: 960 × 6
#>    clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin                                                                                            clin_…¹ clin_…² clin_…³ clin_…⁴ clin_…⁵
#>    <chr>                                                                                                                                                     <chr>   <chr>   <chr>   <chr>   <chr>  
#>  1 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.38… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  2 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.38… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  3 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.38… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  4 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.38… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  5 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.42… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  6 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.42… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  7 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.42… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  8 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.42… gs://f… gs://f… <NA>    <NA>    <NA>   
#>  9 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.42… gs://f… <NA>    <NA>    <NA>    <NA>   
#> 10 gs://firecloud-tcga-open-access/tcga/dcc/coad/clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin/nationwidechildrens.org_COAD.bio.Level_1.42… gs://f… <NA>    <NA>    <NA>    <NA>   
#> # … with 950 more rows, and abbreviated variable names ¹​clin__bio__nationwidechildrens_org__Level_1__auxiliary__clin, ²​clin__bio__nationwidechildrens_org__Level_1__clinical__clin,
#> #   ³​clin__bio__intgen_org__Level_1__auxiliary__clin, ⁴​clin__bio__intgen_org__Level_1__clinical__clin, ⁵​clin__bio__intgen_org__Level_1__biospecimen__clin
names(ct)
#> [1] "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin" "clin__bio__nationwidechildrens_org__Level_1__auxiliary__clin"  
#> [3] "clin__bio__nationwidechildrens_org__Level_1__clinical__clin"    "clin__bio__intgen_org__Level_1__auxiliary__clin"               
#> [5] "clin__bio__intgen_org__Level_1__clinical__clin"                 "clin__bio__intgen_org__Level_1__biospecimen__clin"
```

# Clinical data download

After picking the column in the `getClinicalTable` output, use the
column name as input to the `getClinical` function to obtain the data:

``` r
column_name <- "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin"
clin <- getClinical(
    columnName = column_name,
    participants = TRUE,
    workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
)
#> Using namespace/workspace: broad-firecloud-tcga/TCGA_COAD_OpenAccess_V1-0_DATA
#> 
#> ── Column specification ────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────
#> cols(
#>   .default = col_character(),
#>   admin.day_of_dcc_upload = col_double(),
#>   admin.month_of_dcc_upload = col_double(),
#>   admin.year_of_dcc_upload = col_double(),
#>   patient.additional_studies = col_logical(),
#>   patient.days_to_index = col_double(),
#>   patient.samples.sample.additional_studies = col_logical(),
#>   patient.samples.sample.biospecimen_sequence = col_logical(),
#>   patient.samples.sample.longest_dimension = col_double(),
#>   patient.samples.sample.intermediate_dimension = col_double(),
#>   patient.samples.sample.shortest_dimension = col_double(),
#>   patient.samples.sample.initial_weight = col_double(),
#>   patient.samples.sample.current_weight = col_logical(),
#>   patient.samples.sample.freezing_method = col_logical(),
#>   patient.samples.sample.oct_embedded = col_logical(),
#>   patient.samples.sample.preservation_method = col_logical(),
#>   patient.samples.sample.tissue_type = col_logical(),
#>   patient.samples.sample.composition = col_logical(),
#>   patient.samples.sample.tumor_descriptor = col_logical(),
#>   patient.samples.sample.days_to_collection = col_double(),
#>   patient.samples.sample.time_between_clamping_and_freezing = col_logical()
#>   # ... with 1225 more columns
#> )
#> ℹ Use `spec()` for the full column specifications.
clin[, 1:6]
#> # A tibble: 460 × 6
#>    admin.bcr                      admin.file_uuid                      admin.batch_number admin.project_code admin.disease_code admin.day_of_dcc_upload
#>    <chr>                          <chr>                                <chr>              <chr>              <chr>                                <dbl>
#>  1 nationwide children's hospital a93e6bbe-80de-41a1-9cc6-41fd0f56a4e9 385.38.0           tcga               coad                                     1
#>  2 nationwide children's hospital 8b055cbc-b2ff-4c62-a07c-ccfa44964937 385.38.0           tcga               coad                                     1
#>  3 nationwide children's hospital 61f5baab-8b35-45f4-a188-7d4f3d1a2a8b 422.33.0           tcga               coad                                     1
#>  4 nationwide children's hospital fbad35cb-8be3-4b36-a05d-e93aee1c3975 422.33.0           tcga               coad                                     1
#>  5 nationwide children's hospital 5620a991-2a62-446a-a26e-41ad5c1a92c7 422.33.0           tcga               coad                                     1
#>  6 nationwide children's hospital d7563bda-caea-473f-82fd-905c2bee66ea 422.33.0           tcga               coad                                     1
#>  7 nationwide children's hospital ef41a4ba-feb2-47c2-9292-a0a0680cf9f6 422.33.0           tcga               coad                                     1
#>  8 nationwide children's hospital 96b2bc07-30bf-4e67-b776-371a791249c0 422.33.0           tcga               coad                                     1
#>  9 nationwide children's hospital d1fedef8-53a4-42ff-9cf7-194fd92c004b 76.73.0            tcga               coad                                     1
#> 10 nationwide children's hospital 51c274ce-f952-45da-a0b3-285559d5c361 29.77.0            tcga               coad                                     1
#> # … with 450 more rows
dim(clin)
#> [1]  460 2376
```

# Assay data resources

We use the same approach for assay data. We first produce a list of
assays from the `getAssayTable` and then we select one along with any
sample codes of interest.

``` r
at <- getAssayTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
at
#> # A tibble: 960 × 29
#>    snp__ge…¹ snp__…² snp__…³ snp__…⁴ rnase…⁵ rnase…⁶ rnase…⁷ prote…⁸ rnase…⁹ rnase…˟ methy…˟ rnase…˟ cna__…˟ trans…˟ rnase…˟ mirna…˟ rnase…˟ mirna…˟ rnase…˟ rnase…˟ rnase…˟ rnase…˟ methy…˟ rnase…˟
#>    <chr>     <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>   <chr>  
#>  1 gs://fir… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  2 gs://fir… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  3 gs://fir… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  4 gs://fir… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  5 gs://fir… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  6 gs://fir… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  7 gs://fir… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  8 gs://fir… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… <NA>    gs://f… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#>  9 gs://fir… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#> 10 gs://fir… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… gs://f… <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>    <NA>   
#> # … with 950 more rows, 5 more variables: mirnaseq__illuminahiseq_mirnaseq__bcgsc_ca__Level_3__miR_isoform_expression__data <chr>,
#> #   mirnaseq__illuminahiseq_mirnaseq__bcgsc_ca__Level_3__miR_gene_expression__data <chr>, rnaseq__illuminaga_rnaseq__unc_edu__Level_3__gene_expression__data <chr>,
#> #   rnaseq__illuminaga_rnaseq__unc_edu__Level_3__exon_expression__data <chr>, rnaseq__illuminaga_rnaseq__unc_edu__Level_3__splice_junction_expression__data <chr>, and abbreviated variable names
#> #   ¹​snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_minus_germline_cnv_hg18__seg, ²​snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_hg18__seg,
#> #   ³​snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_hg19__seg, ⁴​snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_minus_germline_cnv_hg19__seg,
#> #   ⁵​rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes__data, ⁶​rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data,
#> #   ⁷​rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_isoforms_normalized__data, ⁸​protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data, …
names(at)
#>  [1] "snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_minus_germline_cnv_hg18__seg"    
#>  [2] "snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_hg18__seg"                       
#>  [3] "snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_hg19__seg"                       
#>  [4] "snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_minus_germline_cnv_hg19__seg"    
#>  [5] "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes__data"                           
#>  [6] "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"                
#>  [7] "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_isoforms_normalized__data"             
#>  [8] "protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data"               
#>  [9] "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__exon_quantification__data"                  
#> [10] "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__junction_quantification__data"              
#> [11] "methylation__humanmethylation450__jhu_usc_edu__Level_3__within_bioassay_data_set_function__data"
#> [12] "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_isoforms__data"                        
#> [13] "cna__illuminahiseq_dnaseqc__hms_harvard_edu__Level_3__segmentation__seg"                        
#> [14] "transcriptome__agilentg4502a_07_3__unc_edu__Level_3__unc_lowess_normalization_gene_level__data" 
#> [15] "rnaseqv2__illuminaga_rnaseqv2__unc_edu__Level_3__RSEM_isoforms_normalized__data"                
#> [16] "mirnaseq__illuminaga_mirnaseq__bcgsc_ca__Level_3__miR_isoform_expression__data"                 
#> [17] "rnaseqv2__illuminaga_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"                   
#> [18] "mirnaseq__illuminaga_mirnaseq__bcgsc_ca__Level_3__miR_gene_expression__data"                    
#> [19] "rnaseqv2__illuminaga_rnaseqv2__unc_edu__Level_3__junction_quantification__data"                 
#> [20] "rnaseqv2__illuminaga_rnaseqv2__unc_edu__Level_3__RSEM_genes__data"                              
#> [21] "rnaseqv2__illuminaga_rnaseqv2__unc_edu__Level_3__RSEM_isoforms__data"                           
#> [22] "rnaseqv2__illuminaga_rnaseqv2__unc_edu__Level_3__exon_quantification__data"                     
#> [23] "methylation__humanmethylation27__jhu_usc_edu__Level_3__within_bioassay_data_set_function__data" 
#> [24] "rnaseq__illuminaga_rnaseq__unc_edu__Level_3__coverage__data"                                    
#> [25] "mirnaseq__illuminahiseq_mirnaseq__bcgsc_ca__Level_3__miR_isoform_expression__data"              
#> [26] "mirnaseq__illuminahiseq_mirnaseq__bcgsc_ca__Level_3__miR_gene_expression__data"                 
#> [27] "rnaseq__illuminaga_rnaseq__unc_edu__Level_3__gene_expression__data"                             
#> [28] "rnaseq__illuminaga_rnaseq__unc_edu__Level_3__exon_expression__data"                             
#> [29] "rnaseq__illuminaga_rnaseq__unc_edu__Level_3__splice_junction_expression__data"
```

# Summary of sample types in the data

You can get a summary table of all the samples in the adata by using the
`sampleTypesTable`:

``` r
sampleTypesTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
#> Using namespace/workspace: broad-firecloud-tcga/TCGA_COAD_OpenAccess_V1-0_DATA
#> # A tibble: 5 × 4
#>   Code  Definition            Short.Letter.Code Frequency
#>   <chr> <chr>                 <chr>                 <dbl>
#> 1 10    Blood Derived Normal  NB                      406
#> 2 11    Solid Tissue Normal   NT                       92
#> 3 06    Metastatic            TM                        1
#> 4 01    Primary Solid Tumor   TP                      460
#> 5 02    Recurrent Solid Tumor TR                        1
```

# Intermediate function for obtaining only the data

Note that if you have the package-wide option set, the workspace
argument is not needed in the function call.

``` r
prot <- getAssayData(
    assayName = "protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
    sampleCode = c("01", "10"),
    workspace = "TCGA_COAD_OpenAccess_V1-0_DATA",
    sampleIdx = 1:4
)
head(prot)
#>                     TCGA-3L-AA1B-01A-21-A45F-20 TCGA-4N-A93T-01A-21-A45F-20 TCGA-4T-AA8H-01A-21-A45F-20 TCGA-5M-AAT5-01A-11-A45F-20
#> 14-3-3_beta-R-V                    -0.080527936                 -0.15754027                  -0.3840605                 -0.08742583
#> 14-3-3_epsilon-M-C                  0.055408025                  0.05978939                   0.1628557                 -0.15276783
#> 14-3-3_zeta-R-V                    -0.002073837                 -0.13374613                   0.2685011                 -0.09958612
#> 4E-BP1-R-V                         -0.026154748                 -0.35821838                   0.3263404                 -0.15502503
#> 4E-BP1_pS65-R-V                    -0.110226155                 -0.15277484                  -0.1381699                 -0.09373361
#> 4E-BP1_pT37_T46-R-V                -0.202870876                 -0.17585007                  -0.1931612                  0.34677646
```

# MultiAssayExperiment

Finally, once you have collected all the relevant column names, these
can be inputs to the main `terraTCGAdata` function:

``` r
mae <- terraTCGAdata(
    clinicalName = "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin",
    assays =
        c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
        "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"),
    sampleCode = NULL,
    split = FALSE,
    sampleIdx = 1:4,
    workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
)
#> Using namespace/workspace: broad-firecloud-tcga/TCGA_COAD_OpenAccess_V1-0_DATA
#> Using namespace/workspace: broad-firecloud-tcga/TCGA_COAD_OpenAccess_V1-0_DATA
#> Warning in .checkBarcodes(barcodes): Inconsistent barcode lengths: 27, 28
#> Using namespace/workspace: broad-firecloud-tcga/TCGA_COAD_OpenAccess_V1-0_DATA
#> 
#> ── Column specification ────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────────
#> cols(
#>   .default = col_character(),
#>   admin.day_of_dcc_upload = col_double(),
#>   admin.month_of_dcc_upload = col_double(),
#>   admin.year_of_dcc_upload = col_double(),
#>   patient.additional_studies = col_logical(),
#>   patient.days_to_index = col_double(),
#>   patient.samples.sample.additional_studies = col_logical(),
#>   patient.samples.sample.biospecimen_sequence = col_logical(),
#>   patient.samples.sample.longest_dimension = col_double(),
#>   patient.samples.sample.intermediate_dimension = col_double(),
#>   patient.samples.sample.shortest_dimension = col_double(),
#>   patient.samples.sample.initial_weight = col_double(),
#>   patient.samples.sample.current_weight = col_logical(),
#>   patient.samples.sample.freezing_method = col_logical(),
#>   patient.samples.sample.oct_embedded = col_logical(),
#>   patient.samples.sample.preservation_method = col_logical(),
#>   patient.samples.sample.tissue_type = col_logical(),
#>   patient.samples.sample.composition = col_logical(),
#>   patient.samples.sample.tumor_descriptor = col_logical(),
#>   patient.samples.sample.days_to_collection = col_double(),
#>   patient.samples.sample.time_between_clamping_and_freezing = col_logical()
#>   # ... with 1225 more columns
#> )
#> ℹ Use `spec()` for the full column specifications.
#> Warning in .checkBarcodes(barcodes): Inconsistent barcode lengths: 27, 28
#> harmonizing input:
#>   removing 455 colData rownames not in sampleMap 'primary'
mae
#> A MultiAssayExperiment object of 2 listed
#>  experiments with user-defined names and respective classes.
#>  Containing an ExperimentList class object of length 2:
#>  [1] protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data: matrix with 200 rows and 4 columns
#>  [2] rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data: matrix with 20531 rows and 4 columns
#> Functionality:
#>  experiments() - obtain the ExperimentList instance
#>  colData() - the primary/phenotype DataFrame
#>  sampleMap() - the sample coordination DataFrame
#>  `$`, `[`, `[[` - extract colData columns, subset, or experiment
#>  *Format() - convert into a long or wide DataFrame
#>  assays() - convert ExperimentList to a SimpleList of matrices
#>  exportClass() - save data to flat files
```

We expect that most `OpenAccess_V1-0` cancer datasets follow this data
model. If you encounter any errors, please provide a minimally
reproducible example at <https://github.com/waldronlab/terraTCGAdata>.

# Session Info

``` r
sessionInfo()
#> R version 4.2.1 Patched (2022-09-26 r82921)
#> Platform: x86_64-pc-linux-gnu (64-bit)
#> Running under: Ubuntu 22.04.1 LTS
#> 
#> Matrix products: default
#> BLAS:   /usr/lib/x86_64-linux-gnu/blas/libblas.so.3.10.0
#> LAPACK: /home/mr148/src/svn/r-4-2/R/lib/R/lib/libRlapack.so
#> 
#> locale:
#>  [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C               LC_TIME=en_US.UTF-8        LC_COLLATE=en_US.UTF-8     LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8    LC_PAPER=en_US.UTF-8      
#>  [8] LC_NAME=C                  LC_ADDRESS=C               LC_TELEPHONE=C             LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       
#> 
#> attached base packages:
#> [1] stats4    stats     graphics  grDevices utils     datasets  methods   base     
#> 
#> other attached packages:
#>  [1] terraTCGAdata_1.1.1         shiny_1.7.2                 testthat_3.1.4              MultiAssayExperiment_1.23.9 SummarizedExperiment_1.27.3 Biobase_2.57.1             
#>  [7] GenomicRanges_1.49.1        GenomeInfoDb_1.33.7         IRanges_2.31.2              S4Vectors_0.35.4            BiocGenerics_0.43.4         MatrixGenerics_1.9.1       
#> [13] matrixStats_0.62.0          AnVIL_1.9.9                 dplyr_1.0.10               
#> 
#> loaded via a namespace (and not attached):
#>  [1] rjson_0.2.21              ellipsis_0.3.2            futile.logger_1.4.3       XVector_0.37.1            rstudioapi_0.14           DT_0.25                   bit64_4.0.5              
#>  [8] AnnotationDbi_1.59.1      fansi_1.0.3               xml2_1.3.3                codetools_0.2-18          cachem_1.0.6              knitr_1.40                pkgload_1.3.0            
#> [15] jsonlite_1.8.0            Rsamtools_2.13.4          dbplyr_2.2.1              png_0.1-7                 BiocManager_1.30.18       readr_2.1.2               compiler_4.2.1           
#> [22] httr_1.4.4                assertthat_0.2.1          Matrix_1.5-1              fastmap_1.1.0             cli_3.4.1                 later_1.3.0               formatR_1.12             
#> [29] htmltools_0.5.3           prettyunits_1.1.1         tools_4.2.1               glue_1.6.2                GenomeInfoDbData_1.2.9    rappdirs_0.3.3            Rcpp_1.0.9               
#> [36] rapiclient_0.1.3          vctrs_0.4.2               Biostrings_2.65.6         rtracklayer_1.57.0        xfun_0.33                 stringr_1.4.1             brio_1.1.3               
#> [43] rvest_1.0.3               mime_0.12                 miniUI_0.1.1.1            lifecycle_1.0.2           restfulr_0.0.15           XML_3.99-0.10             zlibbioc_1.43.0          
#> [50] BiocStyle_2.25.0          vroom_1.5.7               hms_1.1.2                 promises_1.2.0.1          parallel_4.2.1            lambda.r_1.2.4            yaml_2.3.5               
#> [57] curl_4.3.2                memoise_2.0.1             biomaRt_2.53.2            stringi_1.7.8             RSQLite_2.2.17            BiocIO_1.7.1              GenomicDataCommons_1.21.4
#> [64] GenomicFeatures_1.49.7    filelock_1.0.2            BiocParallel_1.31.12      rlang_1.0.6               pkgconfig_2.0.3           bitops_1.0-7              evaluate_0.16            
#> [71] lattice_0.20-45           purrr_0.3.4               GenomicAlignments_1.33.1  htmlwidgets_1.5.4         bit_4.0.4                 tidyselect_1.1.2          magrittr_2.0.3           
#> [78] R6_2.5.1                  generics_0.1.3            DelayedArray_0.23.2       DBI_1.1.3                 pillar_1.8.1              KEGGREST_1.37.3           RCurl_1.98-1.8           
#> [85] tibble_3.1.8              crayon_1.5.1              futile.options_1.0.1      utf8_1.2.2                BiocFileCache_2.5.0       tzdb_0.3.0                rmarkdown_2.16           
#> [92] progress_1.2.2            grid_4.2.1                blob_1.2.3                digest_0.6.29             xtable_1.8-4              tidyr_1.2.1               httpuv_1.6.6             
#> [99] TCGAutils_1.17.3
```

#' @import MultiAssayExperiment AnVIL
NULL

.PARTICIPANT_METADATA_COLS <- c("sample_id", "sample_type", "participant",
    "tcga_sample_id", "submitter_id", "participant_id", "project_id")

.isGDC <- function(workspacename) {
    if (grepl("GDC", workspacename, fixed = TRUE))
        stop("GDC Workspaces are not supported.")
}

#' Obtain the reference table for clinical data
#'
#' The column names in the output table can be used in the `getClinical`
#' function.
#'
#' @inheritParams getClinical
#'
#' @md
#'
#' @return A tibble of Google Storage resource locations e.g.,
#'     `gs://firecloud...`
#'
#' @importFrom AnVILGCP avtable
#'
#' @examples
#' 
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' )
#'     getClinicalTable(
#'         workspace = "TCGA_ACC_OpenAccess_V1-0_DATA"
#'     )
#' 
#' @export
getClinicalTable <-
    function(
        tablename = .DEFAULT_TABLENAME, metacols = .PARTICIPANT_METADATA_COLS,
        workspace = terraTCGAworkspace(), namespace = .DEFAULT_NAMESPACE,
        verbose = TRUE
    )
{
    nwspace <- paste0(namespace, "/", workspace)
    if (verbose)
        message("Using namespace/workspace: ", nwspace)
    .isGDC(workspace)

    avtab <- avtable(
        tablename, namespace = namespace, name = workspace
    )

    metadata <- avtab[, names(avtab) %in% metacols]
    avtab <- avtab[, !names(avtab) %in% metacols]

    avtab[, grep("clin", names(avtab))]
}

#' Obtain clinical data
#'
#' The participant table may contain curated demographic information e.g.,
#' sex, age, etc.
#'
#' @param columnName The name of the column to extract files, see
#'     `getClinicalTable` table. If not provided, the first column in the table
#'     will be used to obtain the clinical information.
#'
#' @param participants logical(1) Whether to merge the participant table
#'     from `avtable("participant")` to the clinical data
#'
#' @param tablename The Terra data model table from which to extract the
#'     clinical data (default: "sample")
#'
#' @param workspace character(1) The Terra Data Resources workspace from which
#'     to pull TCGA data (default: see `terraTCGAworkspace()`). This is set to a
#'     package-wide option.
#'
#' @param namespace character(1) The Terra Workspace Namespace that
#'     defaults to "broad-firecloud-tcga" and rarely needs to be changed.
#'
#' @param verbose logical(1) Whether to output additional information regarding
#'     the workspace and namespace (default: `TRUE`).
#'
#' @param metacols The set of columns that comprise of the metadata columns.
#'     See the `.PARTICIPANT_METADATA_COLS` global variable
#'
#' @param participantIds character() TCGA participant identifiers usually in the
#'     form of "TCGA-AB-1234". By default, all available participant identifiers
#'     will be used. (default: `NULL`)
#'
#' @return A `DataFrame` with clinical information from TCGA. The metadata i.e.,
#'     `metadata(object)` includes the `columnName` used to obtain the data.
#'
#' @export
#'
#' @importFrom AnVILGCP avcopy
#'
#' @md
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' )
#'   getClinical(
#'       workspace = "TCGA_ACC_OpenAccess_V1-0_DATA",
#'       participantIds = c("TCGA-OR-A5J1", "TCGA-OR-A5J2",
#'           "TCGA-OR-A5J3", "TCGA-OR-A5J4")
#'   )
#'
getClinical <-
    function(columnName, participants = TRUE, tablename = .DEFAULT_TABLENAME,
        workspace = terraTCGAworkspace(), namespace = .DEFAULT_NAMESPACE,
        verbose = TRUE, metacols = .PARTICIPANT_METADATA_COLS,
        participantIds = NULL
    )
{
    allclin <- getClinicalTable(
        tablename = tablename, workspace = workspace, namespace = namespace,
        metacols = metacols
    )
    if (missing(columnName))
        columnName <- names(allclin)[1L]
    clinlinks <- allclin[, columnName]
    clinfiles <- unlist(unique(clinlinks))
    if (!is.null(participantIds)) {
        clindex <-
            gsub(".clin.txt", "", basename(clinfiles)) %in% participantIds
        if (!any(clindex))
            stop("'participantIds' not found in clincal files")
        clinfiles <- clinfiles[clindex]
    }
    participantIds <- gsub(".clin.txt", "", basename(clinfiles), fixed = TRUE)

    bfc <- BiocFileCache::BiocFileCache()
    rpath <- BiocFileCache::bfcquery(bfc, columnName, exact = TRUE)[["rpath"]]
    if (!length(rpath)) {
        rpath <- BiocFileCache::bfcnew(bfc, rname = columnName, rtype = "local")
        dir.create(rpath)
        avcopy(clinfiles, rpath)
    }
    dlfiles <- list.files(rpath, full.names = TRUE, pattern = "\\.clin\\.txt$")
    mfiles <- !participantIds %in%
        gsub(".clin.txt", "", basename(dlfiles), fixed = TRUE)
    if (any(mfiles)) {
        clindex <- match(
            participantIds[mfiles], gsub(".clin.txt", "", basename(clinfiles))
        )
        avcopy(clinfiles[clindex], rpath)
    }

    clinrows <- lapply(
        list.files(rpath, full.names = TRUE, pattern = "\\.clin\\.txt$"),
        readr::read_tsv,
        show_col_types = FALSE
    )
    allclins <- lapply(clinrows,
        tidyr::pivot_wider, names_from = "node_name", values_from = "node_value"
    )
    clinical <- dplyr::bind_rows(allclins)
    readr::type_convert(clinical)
}

#' Get an overview of the samples available in the workspace
#'
#' The function provides an overview of samples from the `avtables("sample")`
#' table for the current workspace. Along with the sample codes and frequencies,
#' the output provides a description for each code and the short letter codes.
#'
#' @inheritParams getClinical
#'
#' @return A `tibble` of sample codes and frequency along with their
#'     definition and short letter code
#'
#' @md
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' )
#'   sampleTypesTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
#'
#' @export
sampleTypesTable <-
    function(
        workspace = terraTCGAworkspace(),
        namespace = .DEFAULT_NAMESPACE,
        tablename = .DEFAULT_TABLENAME,
        verbose = TRUE
    )
{
    nwspace <- paste0(namespace, "/", workspace)
    if (verbose)
        message("Using namespace/workspace: ", nwspace)
    avtab <- avtable(tablename, namespace = namespace, name = workspace)
    stable <- base::table(avtab[["sample_type"]])
    dataenv <- new.env(parent = emptyenv())
    utils::data("sampleTypes", envir = dataenv, package = "TCGAutils")
    stypes <- dataenv[["sampleTypes"]]
    sidx <- match(names(stable), stypes[["Short.Letter.Code"]])
    rest <- cbind(stypes[sidx, ], Frequency = as.numeric(stable))
    rownames(rest) <- NULL
    dplyr::as_tibble(rest)
}

.DEFAULT_TABLENAME <- "sample"
.DEFAULT_NAMESPACE <- "broad-firecloud-tcga"

#' Obtain a reference table for assay data in the Terra data model
#'
#' The column names in the output can be used in the `getAssayData` function.
#'
#' @inheritParams getAssayData
#'
#' @md
#'
#' @return A tibble of pointers to resources within the Terra data model
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' )
#'   getAssayTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
#'
#' @export
getAssayTable <-
    function(
        tablename = .DEFAULT_TABLENAME, metacols = .PARTICIPANT_METADATA_COLS,
        workspace = terraTCGAworkspace(), namespace = .DEFAULT_NAMESPACE
    )
{
    .isGDC(workspace)
    samples <- avtable(
        table = tablename, namespace = namespace, name = workspace
    )
    metadata <- samples[, names(samples) %in% metacols]
    samples <- samples[, !names(samples) %in% metacols]
    samples[, grep("clin", names(samples), invert = TRUE)]
}

#' Obtain assay datasets from Terra
#'
#' @inheritParams getClinical
#'
#' @param assayName character() The name of the assay dataset column from
#'     `getAssayTable` to import into the current workspace.
#'
#' @param sampleCode character(1) The sample code used to filtering samples
#'     e.g., "01" for Primary Solid Tumors, see
#'     `data("sampleTypes", package = "TCGAutils")` for reference
#'
#' @param sampleIdx numeric() index or TRUE. Specify an index for subsetting the
#'     assay data. This argument is mainly used for example and vignette
#'     purposes. To use all the data, use the default value (default: `TRUE`)
#'
#' @return Either a matrix or RaggedExperiment depending on the assay selected
#'
#' @seealso [getAssayTable()]
#'
#' @md
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' )
#'   getAssayData(
#'       assayName = "protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
#'       sampleCode = c("01", "10"),
#'       workspace = "TCGA_ACC_OpenAccess_V1-0_DATA"
#'   )
#'
#' @export
getAssayData <-
    function(assayName, sampleCode = "01", tablename = .DEFAULT_TABLENAME,
        workspace = terraTCGAworkspace(), namespace = .DEFAULT_NAMESPACE,
        metacols = .PARTICIPANT_METADATA_COLS, sampleIdx = TRUE
    )
{
    if (missing(assayName))
        stop("Select an assay name from 'getAssayTable'")

    assayTable <- getAssayTable(
        tablename = tablename, metacols = metacols,
        workspace = workspace, namespace = namespace
    )
    assaylinks <- stats::na.omit(assayTable[, assayName])
    assayfiles <- unlist(unique(assaylinks))
    if (length(assayfiles[sampleIdx]) > 800)
        assayfiles <- split(
            assayfiles,
            cut(seq_along(assayfiles), 3,
            labels = utils::head(letters, 3))
        )

    bfc <- BiocFileCache::BiocFileCache()
    rpath <- BiocFileCache::bfcquery(bfc, assayName, exact = TRUE)[["rpath"]]
    if (!length(rpath)) {
        rpath <- BiocFileCache::bfcnew(bfc, rname = assayName, rtype = "local")
        dir.create(rpath)
        if (is.list(assayfiles))
            lapply(assayfiles, avcopy, destination = rpath)
        else
            avcopy(assayfiles[sampleIdx], rpath)
    }

    assaydl <- list.files(rpath, pattern = "\\.txt", full.names = TRUE)
    dfiles <- assaydl[sampleIdx]
    suffix <-
        if (grepl("^cna|snp", assayName)) { ".seg.txt" } else { ".data.txt" }
    tcgaids <- gsub(suffix, "", basename(dfiles), fixed = TRUE)
    if (!missing(sampleCode) && .is_character(sampleCode) && !is.null(sampleCode))
        tcgaids <- tcgaids[
            TCGAutils::TCGAsampleSelect(tcgaids, sampleCodes = sampleCode)
        ]
    assayselect <- file.path(rpath, paste0(tcgaids, suffix))
    datarows <- lapply(
        assayselect,
        readr::read_tsv,
        show_col_types = FALSE
    )
    if (grepl("seg", suffix)) {
        .mergeRangedSamples(datarows)
    } else {
        cnames <- unlist(datarows[[1]][1, ], use.names = FALSE)
        datarows <- lapply(datarows, function(x) x[-1, ])
        rowlist <- lapply(datarows, `[[`, 1L)
        dataonly <- lapply(datarows, function(x) {
            suppressMessages(readr::type_convert(x[2L]))
        })
        dups <- rowlist[!duplicated(rowlist)]
        logilist <- vector("list", length(dups))
        bindlist <- vector("list", length(dups))
        for (i in seq_along(dups)) {
            logilist[[i]] <-
                vapply(
                    rowlist,
                    function(rl) identical(rl, dups[[i]]),
                    logical(1L)
                )
            bindlist[[i]] <-
                cbind(rownames = dups[[i]],
                    dplyr::bind_cols(dataonly[logilist[[i]]]))
        }
        df <- Reduce(function(...) {
            merge(..., all = TRUE, by = "rownames")
        }, bindlist)
        rownames(df) <- df[["rownames"]]
        data.matrix(df[, -1])
    }
}

#' Import Terra TCGA data as a list
#'
#' @inheritParams getAssayData
#'
#' @param assayNames character() A vector of assays selected from the colnames
#'     of `getAssayTable`.
#'
#' @param verbose logical(1L) Whether to output additional details of the
#'   data facilitation.
#'
#' @return A `list` of assay datasets
#'
#' @md
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' )
#'   getTCGAdatalist(
#'       assayNames = c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
#'       "snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_minus_germline_cnv_hg18__seg"),
#'       sampleCode = c("01", "10"),
#'       workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
#'   )
#'
#' @export
getTCGAdatalist <-
    function(
        assayNames, sampleCode, workspace = terraTCGAworkspace(),
        namespace = .DEFAULT_NAMESPACE, tablename = .DEFAULT_TABLENAME,
        sampleIdx = TRUE, verbose = TRUE 
    )
{
    nwspace <- paste0(namespace, "/", workspace)
    if (verbose)
        message("Using namespace/workspace: ", nwspace)
    dlist <- structure(vector("list", length(assayNames)), .Names = assayNames)
    for (assay in assayNames) {
        dlist[[assay]] <-
            getAssayData(
                assay, sampleCode = sampleCode, tablename = tablename,
                workspace = workspace, namespace = namespace,
                sampleIdx = sampleIdx
            )
    }
    dlist
}

#' Obtain a MultiAssayExperiment from the Terra workspace
#'
#' Workspaces on Terra come pre-loaded with TCGA Data. The examples in the
#' documentation correspond to the TCGA_COAD_OpenAccess_V1 workspace that
#' can be found on \url{app.terra.bio}.
#'
#' @inheritParams getClinical
#' @inheritParams getAssayData
#'
#' @param clinicalName character(1) The column name taken from
#'     `getClinicalTable()` and downloaded to be included as the `colData`.
#'
#' @param assays character() A character vector of assay names taken from
#'     `getAssayTable()`
#'
#' @param sampleCode character() A character vector of sample codes from
#'     `sampleTypesTable()`. By default, (NULL) all samples are downloaded and
#'     kept in the data.
#'
#' @param split logical(1L) Whether or not to split the `MultiAssayExperiment`
#'     by sample types using `splitAssays` helper function (default FALSE).
#'
#' @return A `MultiAssayExperiment` object with n number of assays corresponding
#'     to the `assays` argument.
#'
#' @md
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP")
#' )
#'   terraTCGAdata(
#'       clinicalName = "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin",
#'       assays = c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
#'       "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"),
#'       workspace = "TCGA_COAD_OpenAccess_V1-0_DATA",
#'       sampleCode = NULL,
#'       sampleIdx = 1:4,
#'       split = FALSE
#'   )
#'
#' @export
terraTCGAdata <-
    function(
        clinicalName, assays, participants = TRUE,
        sampleCode = NULL, split = FALSE,
        workspace = terraTCGAworkspace(), namespace = .DEFAULT_NAMESPACE,
        tablename = .DEFAULT_TABLENAME, verbose = TRUE, sampleIdx = TRUE
    )
{
    nwspace <- paste0(namespace, "/", workspace)
    if (verbose)
        message("Using namespace/workspace: ", nwspace)
    datalist <- getTCGAdatalist(
        assayNames = assays, sampleCode = sampleCode, workspace = workspace,
        namespace = namespace, tablename = tablename, sampleIdx = sampleIdx,
        verbose = verbose 
    )
    explist <- methods::as(datalist, "ExperimentList")
    partIds <- TCGAutils::TCGAbarcode(
        unique(unlist(colnames(explist), use.names = FALSE))
    )
    coldata <- getClinical(
        columnName = clinicalName, workspace = workspace,
        namespace = namespace, participantIds = partIds, verbose = verbose 
    )
    coldata <- .transform_clinical_to_coldata(
        clinical_data = coldata,
        columnName = clinicalName,
        participants = participants,
        workspace = workspace,
        namespace = namespace
    )
    samap <- TCGAutils::generateMap(datalist, coldata, TCGAutils::TCGAbarcode)
    mae <- MultiAssayExperiment(
        experiments = datalist, colData = coldata, sampleMap = samap
    )
    if (split && (length(sampleCode) || !is.null(sampleCode))) {
        TCGAutils::TCGAsplitAssays(
            mae, sampleCodes = sampleCode, exclusive = TRUE
        )
    } else {
        mae
    }
}

#' @importFrom AnVILGCP avtable
.transform_clinical_to_coldata <-
    function(clinical_data, columnName, participants, workspace, namespace)
{
    coldata <- as.data.frame(clinical_data)
    if (!is.null(coldata[["patient.bcr_patient_barcode"]])) {
        rownames(coldata) <- coldata[["participant_id"]] <-
            toupper(coldata[["patient.bcr_patient_barcode"]])
        if (participants) {
            parts <- avtable(
                table = "participant", namespace = namespace, name = workspace
            )
            parts <- methods::as(parts, "DataFrame")
            rownames(parts) <- parts[["participant_id"]]
            ## replace munged COAD with TCGA
            parts[["participant_id"]] <-
                gsub("^[A-Z]{4}", "TCGA", parts[["participant_id"]])
            coldata <- merge(
                parts, coldata, by = "participant_id",
            )
            rownames(coldata) <- coldata[["participant_id"]]
        }
        coldata <- methods::as(coldata, "DataFrame")
    }
    S4Vectors::metadata(coldata)[["columnName"]] <- columnName
    coldata
}

.is_character <- function(x, na.ok = FALSE, zchar = FALSE)
{
    is.character(x) &&
        (na.ok || all(!is.na(x))) &&
        (zchar || all(nzchar(x)))
}

.is_scalar_character <- function(x, na.ok = FALSE, zchar = FALSE)
    length(x) == 1L && .is_character(x, na.ok, zchar)


.is_scalar_logical <- function(x, na.ok = FALSE) {
    is.logical(x) && length(x) == 1L && (na.ok || !is.na(x))
}

.mergeRangedSamples <- function(sample_list) {
    sample_names <- vapply(
        sample_list, function(x) { unique(x[["Sample"]]) }, character(1L)
    )
    samples <- lapply(sample_list, function(x) x[, names(x) != "Sample"])
    names(samples) <- sample_names
    listgranges <- lapply(
        samples, GenomicRanges::makeGRangesFromDataFrame,
        keep.extra.columns = TRUE
    )
    grls <- methods::as(listgranges, "GRangesList")
    RaggedExperiment::RaggedExperiment(grls)
}

.isSingleChar <- function(ch) {
    stopifnot(is.character(ch), !is.na(ch), identical(length(ch), 1L))
}

#' Obtain or set the Terra Workspace Project Dataset
#'
#' Terra allows access to about 71 open access TCGA datasets. A dataset
#' workspace can be set using the `terraTCGAworkspace` function with a
#' `projectName` input. Use the `selectTCGAworkspace` function to select
#' a TCGA data workspace from an interactive table.
#'
#' @details
#'   Note that GDC workspaces are not supported and are excluded
#'   from the search results. GDC workspaces use a Terra workflow to download
#'   TCGA data rather than providing Google Bucket storage locations for easy
#'   data retrieval. To reset the `terraTCGAworkspace`, use
#'   `terraTCGAworkspace(NULL)` and you will be prompted to select from a list
#'   of TCGA workspaces. You may also check the current active workspace by
#'   running `terraTCGAworkspace()` without any inputs.
#'
#' @aliases selectTCGAworkspace
#'
#' @param projectName character(1) A project code usually in the form of
#'   `TCGA_CODE_OpenAccess_V1-0_DATA`. See `selectTCGAworkspace` to
#'   interactively select from a table of project codes.
#'
#' @param verbose logical(1) Whether to provide more informative messages
#'   when an the "terraTCGAdata.workspace" option is set.
#'
#' @param ... further arguments passed down to lower level functions, not
#'   intended for the end user.
#'
#' @return A Terra TCGA Workspace name
#'
#' @md
#'
#' @examples
#' if (
#'     AnVILGCP::gcloud_exists() &&
#'     identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
#'     nzchar(AnVILGCP::avworkspace_name())
#' ) {
#'   selectTCGAworkspace()
#'   terraTCGAworkspace()
#' }
#'
#' @export
terraTCGAworkspace <-
    function(projectName = getOption("terraTCGAdata.workspace", NULL))
{
    if (!is.null(projectName))
        opt <- .validateWorkspace(projectName = projectName)
    else
        opt <- selectTCGAworkspace(projectName = projectName)
    if (is.null(opt) || !nzchar(opt))
        warning("'terraTCGAdata.workspace' is blank; see '?terraTCGAworkspace'")
    opt
}

.validateWorkspace <- 
    function(projectName)
{
    .isSingleChar(projectName)
    tcga_choices <- .getWorkspaceTable()[["name"]]
    validPC <- projectName %in% tcga_choices
    if (!validPC)
        stop("'projectName' not in the 'selectTCGAworkspace()' table ")
    ws <- getOption("terraTCGAdata.workspace", NULL)
    if (!identical(ws, projectName) && !is.null(ws)) {
        warning(
            "'terraTCGAData.workspace' option set to ",
            sQuote(projectName, q = FALSE),
            " from ",
            sQuote(ws, q = FALSE),
            call. = FALSE
        )
        ws <- projectName
        options("terraTCGAdata.workspace" = projectName)
    }
    ws
}

.done_fun <- function(avs, row_selected) {
    unname(unlist(avs[row_selected, "name"]))
}

## from AnVIL:::.workspaces()
#' @importFrom AnVILGCP avworkspaces
.workspaces <- local({
    workspaces <- NULL
    function() {
        if (is.null(workspaces))
            workspaces <<- avworkspaces()
        workspaces
    }
})

#' Obtain the table of datasets from the Terra platform
#' 
#' The datasets include all TCGA datasets that do not come from the Genomic
#' Data Commons Data Repository because those data use a different data model.
#' 
#' @param project character(1) A prefix for the regex search across all public
#' projects on the terra platform (default: `"^TCGA"`). Usually, this does not
#' change.
#'
#' @param cancerCode character(1) Corresponds to the TCGA cancer code (e.g,
#'   "ACC" for AdrenoCortical Carcinoma) of interest. The default value of
#'   (`.*`) provides all available cancer datasets.
#'
#' @keywords internal
#' 
#' @return A `tibble` `data.frame` that match the project in put; by default,
#'   TCGA workspaces.
.getWorkspaceTable <- function(project = "^TCGA", cancerCode = ".*") {
    avs <- .workspaces()
    gdcind <- grep("GDCDR", avs[["name"]], invert = TRUE)
    avs <- avs[gdcind, ]
    project_code <- paste(project = project, cancerCode = cancerCode, sep = "_")
    ind <- grep(project_code, avs[["name"]])
    avs[ind, ]
}

#' @describeIn terraTCGAworkspace Function to interactively select from the
#'   available TCGA data workspaces in Terra. The `projectName` argument and
#'   'terraTCGAdata.workspace' option must be `NULL` to enable the interactive
#'   gadget.
#'
#' @export
selectTCGAworkspace <- function(
    projectName = getOption("terraTCGAdata.workspace", NULL), verbose = FALSE, ...
) {
    wst <- .getWorkspaceTable(...)
    if (interactive() && is.null(projectName)) {
        ws <- AnVIL::.gadget_run(
            "Terra TCGA Workspaces", wst, .done_fun
        )
        if (verbose)
            message("Setting 'terraTCGAdata.workspace' option to ", ws)
    } else {
        ws <- projectName    
    }
    options("terraTCGAdata.workspace" = ws)
    ws
}

test_that("terraTCGAworkspace works", {
    skip_if_not(
        AnVILGCP::gcloud_exists() &&
        identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
        nzchar(AnVILGCP::avworkspace_name())
    )
    
    ## Blank not in validation table
    withr::with_options(
        list("terraTCGAdata.workspace" = ""),
        expect_error(
            terraTCGAworkspace()
        )
    )

    withr::with_options(
        list("terraTCGAdata.workspace" = NULL),
        expect_warning(
            terraTCGAworkspace()
        )
    )

    withr::with_options(
        list("terraTCGAdata.workspace" = "TCGA_ACC_OpenAccess_V1-0_DATA"),
        expect_identical(
            terraTCGAworkspace(),
            "TCGA_ACC_OpenAccess_V1-0_DATA"
        )
    )

    ## Replacement when input provided
    expect_warning(
        withr::with_options(
            list("terraTCGAdata.workspace" = "TCGA_ACC_OpenAccess_V1-0_DATA"),
            expect_identical(
                terraTCGAworkspace("TCGA_TGCT_OpenAccess_V1-0_DATA"),
                "TCGA_TGCT_OpenAccess_V1-0_DATA"
            )
        )
    )

    expect_error(
        terraTCGAworkspace("ABDC")
    )
})

## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, cache = TRUE)
isAnVILWS <- function() {
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP")
}

## ----eval=FALSE---------------------------------------------------------------
# if (!require("BiocManager", quietly = TRUE))
#     install.packages("BiocManager")
# 
# BiocManager::install("terraTCGAdata")

## ----include=TRUE,results="hide",message=FALSE,warning=FALSE------------------
library(AnVIL)
library(terraTCGAdata)

## -----------------------------------------------------------------------------
gcloud_exists()

## ----eval=isAnVILWS()---------------------------------------------------------
# gcloud_project()

## ----eval=isAnVILWS()---------------------------------------------------------
# selectTCGAworkspace()

## ----eval=isAnVILWS()---------------------------------------------------------
# terraTCGAworkspace("TCGA_COAD_OpenAccess_V1-0_DATA")
# getOption("terraTCGAdata.workspace")

## ----eval=isAnVILWS()---------------------------------------------------------
# ct <- getClinicalTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
# ct
# names(ct)

## ----eval=isAnVILWS()---------------------------------------------------------
# column_name <- "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin"
# clin <- getClinical(
#     columnName = column_name,
#     participants = TRUE,
#     workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
# )
# clin[, 1:6]
# dim(clin)

## ----eval=isAnVILWS()---------------------------------------------------------
# at <- getAssayTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
# at
# names(at)

## ----eval=isAnVILWS()---------------------------------------------------------
# sampleTypesTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")

## ----eval=isAnVILWS()---------------------------------------------------------
# prot <- getAssayData(
#     assayName = "protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
#     sampleCode = c("01", "10"),
#     workspace = "TCGA_COAD_OpenAccess_V1-0_DATA",
#     sampleIdx = 1:4
# )
# head(prot)

## ----eval=isAnVILWS()---------------------------------------------------------
# mae <- terraTCGAdata(
#     clinicalName = "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin",
#     assays =
#         c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
#         "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"),
#     sampleCode = NULL,
#     split = FALSE,
#     sampleIdx = 1:4,
#     workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
# )
# mae

## -----------------------------------------------------------------------------
sessionInfo()

---
title: "terraTCGAdata Introduction"
author: "Marcel Ramos"
date: "`r format(Sys.Date(), '%B %d, %Y')`"
vignette: >
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteIndexEntry{Obtain Terra TCGA data as MultiAssayExperiment}
  %\VignetteEncoding{UTF-8}
output:
  BiocStyle::html_document:
    number_sections: yes
    toc: true
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE, cache = TRUE)
isAnVILWS <- function() {
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP")
}
```

# terraTCGAData

## Installation

```{r,eval=FALSE}
if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("terraTCGAdata")
```

# Overview
 
The `terraTCGAdata` R package aims to import TCGA datasets, as
[MultiAssayExperiment](http://bioconductor.org/packages/MultiAssayExperiment/),
available on the Terra platform. The package provides a set of
functions that allow the discovery of relevant datasets. It provides
one main function and two helper functions:
 
1.  `terraTCGAdata` allows the creation of the `MultiAssayExperiment` object
    from the different indicated resources.
 
2.  The `getClinicalTable` and `getAssayTable` functions allow for the
    discovery of datasets within the Terra data model. The column names
    from these tables can be provided as inputs to the `terraTCGAdata`
    function.

## Data

Some public Terra workspaces come pre-packaged with TCGA data (i.e., cloud data
resources are linked within the data model). Particularly the workspaces that
are labelled `OpenAccess_V1-0`. Datasets harmonized to the hg38 genome, such as
those from the Genomic Data Commons data repository, use a different data model
/ workflow and are not compatible with the functions in this package. For those
that are, we make use of the Terra data model and represent the data as
`MultiAssayExperiment`.

For more information on `MultiAssayExperiment`, please see the vignette in
that package.

# Requirements

## Loading packages

```{r,include=TRUE,results="hide",message=FALSE,warning=FALSE}
library(AnVIL)
library(terraTCGAdata)
```

## gcloud sdk installation

A valid GCloud SDK installation is required to use the package. To get set up,
see the Bioconductor tutorials for running RStudio on Terra. Use the
`gcloud_exists()` function from the `r BiocStyle::Biocpkg("AnVIL")` package to
identify whether it is installed in your system.

```{r}
gcloud_exists()
```

You can also use the `gcloud_project` to set a project name by specifying
the project argument:

```{r, eval=isAnVILWS()}
gcloud_project()
```

# Default Data Workspace

To get a table of available TCGA workspaces, use the `selectTCGAworkspace()`
function: 

```{r, eval=isAnVILWS()}
selectTCGAworkspace()
```

You can also set the package-wide option with the `terraTCGAworkspace` function
and check the setting with `getOption('terraTCGAdata.workspace')` or by running
`terraTCGAworkspace` function.

```{r,eval=isAnVILWS()}
terraTCGAworkspace("TCGA_COAD_OpenAccess_V1-0_DATA")
getOption("terraTCGAdata.workspace")
```

# Clinical data resources

In order to determine what datasets to download, use the `getClinicalTable`
function to list all of the columns that correspond to clinical data
from the different collection centers.

```{r, eval=isAnVILWS()}
ct <- getClinicalTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
ct
names(ct)
```

# Clinical data download

After picking the column in the `getClinicalTable` output, use the column
name as input to the `getClinical` function to obtain the data:

```{r, eval=isAnVILWS()}
column_name <- "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin"
clin <- getClinical(
    columnName = column_name,
    participants = TRUE,
    workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
)
clin[, 1:6]
dim(clin)
```

# Assay data resources

We use the same approach for assay data. We first produce a list of assays
from the `getAssayTable` and then we select one along with any sample
codes of interest.

```{r, eval=isAnVILWS()}
at <- getAssayTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
at
names(at)
```

# Summary of sample types in the data

You can get a summary table of all the samples in the adata by using the
`sampleTypesTable`:

```{r, eval=isAnVILWS()}
sampleTypesTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")
```

# Intermediate function for obtaining only the data

Note that if you have the package-wide option set, the workspace argument
is not needed in the function call.

```{r, eval=isAnVILWS()}
prot <- getAssayData(
    assayName = "protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
    sampleCode = c("01", "10"),
    workspace = "TCGA_COAD_OpenAccess_V1-0_DATA",
    sampleIdx = 1:4
)
head(prot)
```

# MultiAssayExperiment

Finally, once you have collected all the relevant column names, 
these can be inputs to the main `terraTCGAdata` function:

```{r, eval=isAnVILWS()}
mae <- terraTCGAdata(
    clinicalName = "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin",
    assays =
        c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
        "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"),
    sampleCode = NULL,
    split = FALSE,
    sampleIdx = 1:4,
    workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
)
mae
```

We expect that most `OpenAccess_V1-0` cancer datasets follow this data model.
If you encounter any errors, please provide a minimally reproducible example
at https://github.com/waldronlab/terraTCGAdata.

# Session Info

```{r}
sessionInfo()
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clinical.R
\name{sampleTypesTable}
\alias{sampleTypesTable}
\title{Get an overview of the samples available in the workspace}
\usage{
sampleTypesTable(
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE,
  tablename = .DEFAULT_TABLENAME,
  verbose = TRUE
)
}
\arguments{
\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}

\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{verbose}{logical(1) Whether to output additional information regarding
the workspace and namespace (default: \code{TRUE}).}
}
\value{
A \code{tibble} of sample codes and frequency along with their
definition and short letter code
}
\description{
The function provides an overview of samples from the \code{avtables("sample")}
table for the current workspace. Along with the sample codes and frequencies,
the output provides a description for each code and the short letter codes.
}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
)
  sampleTypesTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terraTCGAdata.R
\name{getAssayTable}
\alias{getAssayTable}
\title{Obtain a reference table for assay data in the Terra data model}
\usage{
getAssayTable(
  tablename = .DEFAULT_TABLENAME,
  metacols = .PARTICIPANT_METADATA_COLS,
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE
)
}
\arguments{
\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{metacols}{The set of columns that comprise of the metadata columns.
See the \code{.PARTICIPANT_METADATA_COLS} global variable}

\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}
}
\value{
A tibble of pointers to resources within the Terra data model
}
\description{
The column names in the output can be used in the \code{getAssayData} function.
}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
)
  getAssayTable(workspace = "TCGA_COAD_OpenAccess_V1-0_DATA")

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terraTCGAworkspaces.R
\name{terraTCGAworkspace}
\alias{terraTCGAworkspace}
\alias{selectTCGAworkspace}
\title{Obtain or set the Terra Workspace Project Dataset}
\usage{
terraTCGAworkspace(projectName = getOption("terraTCGAdata.workspace", NULL))

selectTCGAworkspace(
  projectName = getOption("terraTCGAdata.workspace", NULL),
  verbose = FALSE,
  ...
)
}
\arguments{
\item{projectName}{character(1) A project code usually in the form of
\verb{TCGA_CODE_OpenAccess_V1-0_DATA}. See \code{selectTCGAworkspace} to
interactively select from a table of project codes.}

\item{verbose}{logical(1) Whether to provide more informative messages
when an the "terraTCGAdata.workspace" option is set.}

\item{...}{further arguments passed down to lower level functions, not
intended for the end user.}
}
\value{
A Terra TCGA Workspace name
}
\description{
Terra allows access to about 71 open access TCGA datasets. A dataset
workspace can be set using the \code{terraTCGAworkspace} function with a
\code{projectName} input. Use the \code{selectTCGAworkspace} function to select
a TCGA data workspace from an interactive table.
}
\details{
Note that GDC workspaces are not supported and are excluded
from the search results. GDC workspaces use a Terra workflow to download
TCGA data rather than providing Google Bucket storage locations for easy
data retrieval. To reset the \code{terraTCGAworkspace}, use
\code{terraTCGAworkspace(NULL)} and you will be prompted to select from a list
of TCGA workspaces. You may also check the current active workspace by
running \code{terraTCGAworkspace()} without any inputs.
}
\section{Functions}{
\itemize{
\item \code{selectTCGAworkspace()}: Function to interactively select from the
available TCGA data workspaces in Terra. The `projectName` argument and
'terraTCGAdata.workspace' option must be `NULL` to enable the interactive
gadget.

}}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
) {
  selectTCGAworkspace()
  terraTCGAworkspace()
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clinical.R
\name{getClinical}
\alias{getClinical}
\title{Obtain clinical data}
\usage{
getClinical(
  columnName,
  participants = TRUE,
  tablename = .DEFAULT_TABLENAME,
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE,
  verbose = TRUE,
  metacols = .PARTICIPANT_METADATA_COLS,
  participantIds = NULL
)
}
\arguments{
\item{columnName}{The name of the column to extract files, see
\code{getClinicalTable} table. If not provided, the first column in the table
will be used to obtain the clinical information.}

\item{participants}{logical(1) Whether to merge the participant table
from \code{avtable("participant")} to the clinical data}

\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}

\item{verbose}{logical(1) Whether to output additional information regarding
the workspace and namespace (default: \code{TRUE}).}

\item{metacols}{The set of columns that comprise of the metadata columns.
See the \code{.PARTICIPANT_METADATA_COLS} global variable}

\item{participantIds}{character() TCGA participant identifiers usually in the
form of "TCGA-AB-1234". By default, all available participant identifiers
will be used. (default: \code{NULL})}
}
\value{
A \code{DataFrame} with clinical information from TCGA. The metadata i.e.,
\code{metadata(object)} includes the \code{columnName} used to obtain the data.
}
\description{
The participant table may contain curated demographic information e.g.,
sex, age, etc.
}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
)
  getClinical(
      workspace = "TCGA_ACC_OpenAccess_V1-0_DATA",
      participantIds = c("TCGA-OR-A5J1", "TCGA-OR-A5J2",
          "TCGA-OR-A5J3", "TCGA-OR-A5J4")
  )

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terraTCGAworkspaces.R
\name{.getWorkspaceTable}
\alias{.getWorkspaceTable}
\title{Obtain the table of datasets from the Terra platform}
\usage{
.getWorkspaceTable(project = "^TCGA", cancerCode = ".*")
}
\arguments{
\item{project}{character(1) A prefix for the regex search across all public
projects on the terra platform (default: `"^TCGA"`). Usually, this does not
change.}

\item{cancerCode}{character(1) Corresponds to the TCGA cancer code (e.g,
"ACC" for AdrenoCortical Carcinoma) of interest. The default value of
(`.*`) provides all available cancer datasets.}
}
\value{
A `tibble` `data.frame` that match the project in put; by default,
  TCGA workspaces.
}
\description{
The datasets include all TCGA datasets that do not come from the Genomic
Data Commons Data Repository because those data use a different data model.
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terraTCGAdata.R
\name{terraTCGAdata}
\alias{terraTCGAdata}
\title{Obtain a MultiAssayExperiment from the Terra workspace}
\usage{
terraTCGAdata(
  clinicalName,
  assays,
  participants = TRUE,
  sampleCode = NULL,
  split = FALSE,
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE,
  tablename = .DEFAULT_TABLENAME,
  verbose = TRUE,
  sampleIdx = TRUE
)
}
\arguments{
\item{clinicalName}{character(1) The column name taken from
\code{getClinicalTable()} and downloaded to be included as the \code{colData}.}

\item{assays}{character() A character vector of assay names taken from
\code{getAssayTable()}}

\item{participants}{logical(1) Whether to merge the participant table
from \code{avtable("participant")} to the clinical data}

\item{sampleCode}{character() A character vector of sample codes from
\code{sampleTypesTable()}. By default, (NULL) all samples are downloaded and
kept in the data.}

\item{split}{logical(1L) Whether or not to split the \code{MultiAssayExperiment}
by sample types using \code{splitAssays} helper function (default FALSE).}

\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}

\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{verbose}{logical(1) Whether to output additional information regarding
the workspace and namespace (default: \code{TRUE}).}

\item{sampleIdx}{numeric() index or TRUE. Specify an index for subsetting the
assay data. This argument is mainly used for example and vignette
purposes. To use all the data, use the default value (default: \code{TRUE})}
}
\value{
A \code{MultiAssayExperiment} object with n number of assays corresponding
to the \code{assays} argument.
}
\description{
Workspaces on Terra come pre-loaded with TCGA Data. The examples in the
documentation correspond to the TCGA_COAD_OpenAccess_V1 workspace that
can be found on \url{app.terra.bio}.
}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP")
)
  terraTCGAdata(
      clinicalName = "clin__bio__nationwidechildrens_org__Level_1__biospecimen__clin",
      assays = c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
      "rnaseqv2__illuminahiseq_rnaseqv2__unc_edu__Level_3__RSEM_genes_normalized__data"),
      workspace = "TCGA_COAD_OpenAccess_V1-0_DATA",
      sampleCode = NULL,
      sampleIdx = 1:4,
      split = FALSE
  )

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terraTCGAdata.R
\name{getAssayData}
\alias{getAssayData}
\title{Obtain assay datasets from Terra}
\usage{
getAssayData(
  assayName,
  sampleCode = "01",
  tablename = .DEFAULT_TABLENAME,
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE,
  metacols = .PARTICIPANT_METADATA_COLS,
  sampleIdx = TRUE
)
}
\arguments{
\item{assayName}{character() The name of the assay dataset column from
\code{getAssayTable} to import into the current workspace.}

\item{sampleCode}{character(1) The sample code used to filtering samples
e.g., "01" for Primary Solid Tumors, see
\code{data("sampleTypes", package = "TCGAutils")} for reference}

\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}

\item{metacols}{The set of columns that comprise of the metadata columns.
See the \code{.PARTICIPANT_METADATA_COLS} global variable}

\item{sampleIdx}{numeric() index or TRUE. Specify an index for subsetting the
assay data. This argument is mainly used for example and vignette
purposes. To use all the data, use the default value (default: \code{TRUE})}
}
\value{
Either a matrix or RaggedExperiment depending on the assay selected
}
\description{
Obtain assay datasets from Terra
}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
)
  getAssayData(
      assayName = "protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
      sampleCode = c("01", "10"),
      workspace = "TCGA_ACC_OpenAccess_V1-0_DATA"
  )

}
\seealso{
\code{\link[=getAssayTable]{getAssayTable()}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clinical.R
\name{getClinicalTable}
\alias{getClinicalTable}
\title{Obtain the reference table for clinical data}
\usage{
getClinicalTable(
  tablename = .DEFAULT_TABLENAME,
  metacols = .PARTICIPANT_METADATA_COLS,
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE,
  verbose = TRUE
)
}
\arguments{
\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{metacols}{The set of columns that comprise of the metadata columns.
See the \code{.PARTICIPANT_METADATA_COLS} global variable}

\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}

\item{verbose}{logical(1) Whether to output additional information regarding
the workspace and namespace (default: \code{TRUE}).}
}
\value{
A tibble of Google Storage resource locations e.g.,
\verb{gs://firecloud...}
}
\description{
The column names in the output table can be used in the \code{getClinical}
function.
}
\examples{

if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
)
    getClinicalTable(
        workspace = "TCGA_ACC_OpenAccess_V1-0_DATA"
    )

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terraTCGAdata.R
\name{getTCGAdatalist}
\alias{getTCGAdatalist}
\title{Import Terra TCGA data as a list}
\usage{
getTCGAdatalist(
  assayNames,
  sampleCode,
  workspace = terraTCGAworkspace(),
  namespace = .DEFAULT_NAMESPACE,
  tablename = .DEFAULT_TABLENAME,
  sampleIdx = TRUE,
  verbose = TRUE
)
}
\arguments{
\item{assayNames}{character() A vector of assays selected from the colnames
of \code{getAssayTable}.}

\item{sampleCode}{character(1) The sample code used to filtering samples
e.g., "01" for Primary Solid Tumors, see
\code{data("sampleTypes", package = "TCGAutils")} for reference}

\item{workspace}{character(1) The Terra Data Resources workspace from which
to pull TCGA data (default: see \code{terraTCGAworkspace()}). This is set to a
package-wide option.}

\item{namespace}{character(1) The Terra Workspace Namespace that
defaults to "broad-firecloud-tcga" and rarely needs to be changed.}

\item{tablename}{The Terra data model table from which to extract the
clinical data (default: "sample")}

\item{sampleIdx}{numeric() index or TRUE. Specify an index for subsetting the
assay data. This argument is mainly used for example and vignette
purposes. To use all the data, use the default value (default: \code{TRUE})}

\item{verbose}{logical(1L) Whether to output additional details of the
data facilitation.}
}
\value{
A \code{list} of assay datasets
}
\description{
Import Terra TCGA data as a list
}
\examples{
if (
    AnVILGCP::gcloud_exists() &&
    identical(AnVILBase::avplatform_namespace(), "AnVILGCP") &&
    nzchar(AnVILGCP::avworkspace_name())
)
  getTCGAdatalist(
      assayNames = c("protein_exp__mda_rppa_core__mdanderson_org__Level_3__protein_normalization__data",
      "snp__genome_wide_snp_6__broad_mit_edu__Level_3__segmented_scna_minus_germline_cnv_hg18__seg"),
      sampleCode = c("01", "10"),
      workspace = "TCGA_COAD_OpenAccess_V1-0_DATA"
  )

}
